@@ -3,19 +3,21 @@ import re
 from abc import ABC, abstractmethod
 from typing import Generator, List, Tuple
 
-from rich import box # type: ignore
-from rich.live import Live # type: ignore
-from rich.panel import Panel # type: ignore
-from rich.text import Text # type: ignore
+from rich import box  # type: ignore
+from rich.live import Live  # type: ignore
+from rich.panel import Panel  # type: ignore
+from rich.text import Text  # type: ignore
 
-from jarvis.jarvis_utils.config import (get_max_input_token_count,
-                                        get_pretty_output, is_print_prompt)
+from jarvis.jarvis_utils.config import (
+    get_max_input_token_count,
+    get_pretty_output,
+    is_print_prompt,
+)
 from jarvis.jarvis_utils.embedding import split_text_into_chunks
 from jarvis.jarvis_utils.globals import set_in_chat
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 from jarvis.jarvis_utils.tag import ct, ot
-from jarvis.jarvis_utils.utils import (get_context_token_count, while_success,
-                                       while_true)
+from jarvis.jarvis_utils.utils import get_context_token_count, while_success, while_true
 
 
 class BasePlatform(ABC):
@@ -25,10 +27,12 @@ class BasePlatform(ABC):
         """Initialize model"""
         self.suppress_output = True  # 添加输出控制标志
         self.web = False  # 添加web属性，默认false
+        self._saved = False
 
     def __del__(self):
         """Destroy model"""
-        self.delete_chat()
+        if not self._saved:
+            self.delete_chat()
 
     @abstractmethod
     def set_model_name(self, model_name: str):
@@ -64,35 +68,38 @@ class BasePlatform(ABC):
             max_chunk_size = get_max_input_token_count() - 1024  # 留出一些余量
             min_chunk_size = get_max_input_token_count() - 2048
             inputs = split_text_into_chunks(message, max_chunk_size, min_chunk_size)
-            print("正在提交长上下文...")
+            print("📤 正在提交长上下文...")
             prefix_prompt = f"""
             我将分多次提供大量内容，在我明确告诉你内容已经全部提供完毕之前，每次仅需要输出"已收到"，明白请输出"开始接收输入"。
             """
             while_true(lambda: while_success(lambda: self.chat(prefix_prompt), 5), 5)
             submit_count = 0
             length = 0
+            response = ""
             for input in inputs:
                 submit_count += 1
                 length += len(input)
                 print(
-                    f"正在提交第{submit_count}部分（共{len(inputs)}部分({length}/{len(message)})）"
+                    f"📤 正在提交第{submit_count}部分（共{len(inputs)}部分({length}/{len(message)})）"
                 )
-                list(
-                    while_true(
-                        lambda: while_success(
-                            lambda: self.chat(
-                                f"<part_content>{input}</part_content>\n\n请返回<已收到>，不需要返回其他任何内容"
-                            ),
-                            5,
+
+                response += "\n"
+                for trunk in while_true(
+                    lambda: while_success(
+                        lambda: self.chat(
+                            f"<part_content>{input}</part_content>\n\n请返回<已收到>，不需要返回其他任何内容"
                         ),
                         5,
-                    )
-                )
+                    ),
+                    5,
+                ):
+                    response += trunk
+
                 print(
-                    f"提交第{submit_count}部分完成，当前进度：{length}/{len(message)}"
+                    f"📤 提交第{submit_count}部分完成，当前进度：{length}/{len(message)}"
                 )
-            print("提交完成 ✅")
-            response = while_true(
+            print("✅ 提交完成")
+            response += "\n" + while_true(
                 lambda: while_success(
                     lambda: self._chat("内容已经全部提供完毕，请根据内容继续"), 5
                 ),
@@ -161,6 +168,9 @@ class BasePlatform(ABC):
             result: str = while_true(
                 lambda: while_success(lambda: self._chat(message), 5), 5
             )
+            from jarvis.jarvis_utils.globals import set_last_message
+
+            set_last_message(result)
             return result
         finally:
             set_in_chat(False)
@@ -170,11 +180,45 @@ class BasePlatform(ABC):
         """Model name"""
         raise NotImplementedError("name is not implemented")
 
+    @classmethod
+    @abstractmethod
+    def platform_name(cls) -> str:
+        """Platform name"""
+        raise NotImplementedError("platform_name is not implemented")
+
     @abstractmethod
     def delete_chat(self) -> bool:
         """Delete chat"""
         raise NotImplementedError("delete_chat is not implemented")
 
+    @abstractmethod
+    def save(self, file_path: str) -> bool:
+        """Save chat session to a file.
+
+        Note:
+            Implementations of this method should set `self._saved = True` upon successful saving
+            to prevent the session from being deleted on object destruction.
+
+        Args:
+            file_path: The path to save the session file.
+
+        Returns:
+            True if saving is successful, False otherwise.
+        """
+        raise NotImplementedError("save is not implemented")
+
+    @abstractmethod
+    def restore(self, file_path: str) -> bool:
+        """Restore chat session from a file.
+
+        Args:
+            file_path: The path to restore the session file from.
+
+        Returns:
+            True if restoring is successful, False otherwise.
+        """
+        raise NotImplementedError("restore is not implemented")
+
     @abstractmethod
     def set_system_prompt(self, message: str):
         """Set system message"""
