@@ -7,9 +7,8 @@ import os
 import time
 from typing import Dict, Generator, List, Tuple
 
-import requests  # type: ignore
-
 from jarvis.jarvis_platform.base import BasePlatform
+from jarvis.jarvis_utils import http
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 from jarvis.jarvis_utils.utils import while_success
 
@@ -22,13 +21,12 @@ class KimiModel(BasePlatform):
     - 消息收发
     """
 
-    platform_name = "kimi"
-
     def get_model_list(self) -> List[Tuple[str, str]]:
         """Get model list"""
         return [
             ("kimi", "基于网页的 Kimi，免费接口"),
             ("k1", "基于网页的 Kimi，深度思考模型"),
+            ("k2", "基于网页的 Kimi，深度思考模型 K2"),
         ]
 
     def __init__(self):
@@ -67,7 +65,7 @@ class KimiModel(BasePlatform):
         }
         try:
             response = while_success(
-                lambda: requests.request("POST", url, headers=headers, data=payload),
+                lambda: http.post(url, headers=headers, data=payload),
                 sleep_time=5,
             )
             if response.status_code != 200:
@@ -95,7 +93,7 @@ class KimiModel(BasePlatform):
         }
 
         response = while_success(
-            lambda: requests.post(url, headers=headers, data=payload), sleep_time=5
+            lambda: http.post(url, headers=headers, data=payload), sleep_time=5
         )
         return response.json()
 
@@ -109,7 +107,7 @@ class KimiModel(BasePlatform):
             with open(file_path, "rb") as f:
                 content = f.read()
                 response = while_success(
-                    lambda: requests.put(presigned_url, data=content), sleep_time=5
+                    lambda: http.put(presigned_url, data=content), sleep_time=5
                 )
                 return response.status_code == 200
         except Exception as e:
@@ -136,7 +134,7 @@ class KimiModel(BasePlatform):
         }
 
         response = while_success(
-            lambda: requests.post(url, headers=headers, data=payload), sleep_time=5
+            lambda: http.post(url, headers=headers, data=payload), sleep_time=5
         )
         return response.json()
 
@@ -152,29 +150,43 @@ class KimiModel(BasePlatform):
         retry_count = 0
 
         while retry_count < max_retries:
-            payload = json.dumps({"ids": [file_id]}, ensure_ascii=False)
-            response = while_success(
-                lambda: requests.post(url, headers=headers, data=payload, stream=True),
+            payload = {"ids": [file_id]}
+            response_stream = while_success(
+                lambda: http.stream_post(url, headers=headers, json=payload),
                 sleep_time=5,
             )
 
-            for line in response.iter_lines():
-                if not line:
-                    continue
+            response_data = b""
 
-                line = line.decode("utf-8")
-                if not line.startswith("data: "):
-                    continue
+            # 处理流式响应
+            for chunk in response_stream:
+                response_data += chunk
 
+                # 尝试解析SSE格式的数据
                 try:
-                    data = json.loads(line[6:])
-                    if data.get("event") == "resp":
-                        status = data.get("file_info", {}).get("status")
-                        if status == "parsed":
-                            return True
-                        elif status == "failed":
-                            return False
-                except json.JSONDecodeError:
+                    # 查找完整的数据行
+                    lines = response_data.decode("utf-8").split("\n")
+                    response_data = b""  # 重置缓冲区
+
+                    for line in lines:
+                        if not line.strip():
+                            continue
+
+                        # SSE格式的行通常以"data: "开头
+                        if line.startswith("data: "):
+                            try:
+                                data = json.loads(line[6:])
+                                if data.get("event") == "resp":
+                                    status = data.get("file_info", {}).get("status")
+                                    if status == "parsed":
+                                        return True
+                                    elif status == "failed":
+                                        return False
+                            except json.JSONDecodeError:
+                                continue
+
+                except UnicodeDecodeError:
+                    # 如果解码失败，继续累积数据
                     continue
 
             retry_count += 1
@@ -187,68 +199,54 @@ class KimiModel(BasePlatform):
         if not file_list:
             return True
 
-        from yaspin import yaspin  # type: ignore
-
         if not self.chat_id:
-            with yaspin(text="创建聊天会话...", color="yellow") as spinner:
-                if not self._create_chat():
-                    yaspin.text = "创建聊天会话失败"
-                    spinner.fail("❌")
-                    return False
-                spinner.text = "创建聊天会话成功"
-                spinner.ok("✅")
+            print("🚀 正在创建聊天会话...")
+            if not self._create_chat():
+                print("❌ 创建聊天会话失败")
+                return False
+            print("✅ 创建聊天会话成功")
 
         uploaded_files = []
         for index, file_path in enumerate(file_list, 1):
             file_name = os.path.basename(file_path)
-            with yaspin(
-                text=f"处理文件 [{index}/{len(file_list)}]: {file_name}", color="yellow"
-            ) as spinner:
-                try:
-                    mime_type, _ = mimetypes.guess_type(file_path)
-                    action = (
-                        "image"
-                        if mime_type and mime_type.startswith("image/")
-                        else "file"
-                    )
+            print(f"🔍 处理文件 [{index}/{len(file_list)}]: {file_name}")
+            try:
+                mime_type, _ = mimetypes.guess_type(file_path)
+                action = (
+                    "image" if mime_type and mime_type.startswith("image/") else "file"
+                )
 
-                    # 获取预签名URL
-                    spinner.text = f"获取上传URL: {file_name}"
-                    presigned_data = self._get_presigned_url(file_path, action)
+                # 获取预签名URL
+                print(f"🔍 获取上传URL: {file_name}")
+                presigned_data = self._get_presigned_url(file_path, action)
 
-                    # 上传文件
-                    spinner.text = f"上传文件: {file_name}"
-                    if self._upload_file(file_path, presigned_data["url"]):
-                        # 获取文件信息
-                        spinner.text = f"获取文件信息: {file_name}"
-                        file_info = self._get_file_info(
-                            presigned_data, file_name, action
-                        )
+                # 上传文件
+                print(f"🔍 上传文件: {file_name}")
+                if self._upload_file(file_path, presigned_data["url"]):
+                    # 获取文件信息
+                    print(f"🔍 获取文件信息: {file_name}")
+                    file_info = self._get_file_info(presigned_data, file_name, action)
 
-                        # 只有文件需要解析
-                        if action == "file":
-                            spinner.text = f"等待文件解析: {file_name}"
-                            if self._wait_for_parse(file_info["id"]):
-                                uploaded_files.append(file_info)
-                                spinner.text = f"文件处理完成: {file_name}"
-                                spinner.ok("✅")
-                            else:
-                                spinner.text = f"❌文件解析失败: {file_name}"
-                                spinner.fail("")
-                                return False
-                        else:
+                    # 只有文件需要解析
+                    if action == "file":
+                        print(f"🔍 等待文件解析: {file_name}")
+                        if self._wait_for_parse(file_info["id"]):
                             uploaded_files.append(file_info)
-                            spinner.write(f"✅图片处理完成: {file_name}")
+                            print(f"✅ 文件处理完成: {file_name}")
+                        else:
+                            print(f"❌ 文件解析失败: {file_name}")
+                            return False
                     else:
-                        spinner.text = f"文件上传失败: {file_name}"
-                        spinner.fail("❌")
-                        return False
-
-                except Exception as e:
-                    spinner.text = f"处理文件出错 {file_path}: {str(e)}"
-                    spinner.fail("❌")
+                        uploaded_files.append(file_info)
+                        print(f"✅ 图片处理完成: {file_name}")
+                else:
+                    print(f"❌ 文件上传失败: {file_name}")
                     return False
 
+            except Exception as e:
+                print(f"❌ 处理文件出错 {file_path}: {str(e)}")
+                return False
+
         self.uploaded_files = uploaded_files
         return True
 
@@ -281,8 +279,9 @@ class KimiModel(BasePlatform):
             "use_search": True if self.web else False,
             "extend": {"sidebar": True},
             "kimiplus_id": "kimi",
-            "use_research": False,
-            "use_math": False,
+            "use_deep_research": False,
+            "use_semantic_memory": True,
+            "history": [],
             "refs": refs,
             "refs_file": refs_file,
             "model": self.model_name,
@@ -294,29 +293,44 @@ class KimiModel(BasePlatform):
         }
 
         try:
-            response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload, stream=True),
+            # 使用新的stream_post接口发送消息请求，获取流式响应
+            response_stream = while_success(
+                lambda: http.stream_post(url, headers=headers, json=payload),
                 sleep_time=5,
             )
-            # 如果禁止输出，则静默处理
-            for line in response.iter_lines():
-                if not line:
-                    continue
 
-                line = line.decode("utf-8")
-                if not line.startswith("data: "):
-                    continue
+            response_data = b""
 
+            # 处理流式响应
+            for chunk in response_stream:
+                response_data += chunk
+
+                # 尝试解析SSE格式的数据
                 try:
-                    data = json.loads(line[6:])
-                    event = data.get("event")
+                    # 查找完整的数据行
+                    lines = response_data.decode("utf-8").split("\n")
+                    response_data = b""  # 重置缓冲区
 
-                    if event == "cmpl":
-                        # 处理补全文本
-                        text = data.get("text", "")
-                        if text:
-                            yield text
-                except json.JSONDecodeError:
+                    for line in lines:
+                        if not line.strip():
+                            continue
+
+                        # SSE格式的行通常以"data: "开头
+                        if line.startswith("data: "):
+                            try:
+                                data = json.loads(line[6:])
+                                event = data.get("event")
+
+                                if event == "cmpl":
+                                    # 处理补全文本
+                                    text = data.get("text", "")
+                                    if text:
+                                        yield text
+                            except json.JSONDecodeError:
+                                continue
+
+                except UnicodeDecodeError:
+                    # 如果解码失败，继续累积数据
                     continue
 
             return None
@@ -337,7 +351,7 @@ class KimiModel(BasePlatform):
 
         try:
             response = while_success(
-                lambda: requests.delete(url, headers=headers), sleep_time=5
+                lambda: http.delete(url, headers=headers), sleep_time=5
             )
             if response.status_code == 200:
                 self.chat_id = ""
@@ -353,10 +367,61 @@ class KimiModel(BasePlatform):
             PrettyOutput.print(f"删除会话时发生错误: {str(e)}", OutputType.ERROR)
             return False
 
+    def save(self, file_path: str) -> bool:
+        """Save chat session to a file."""
+        if not self.chat_id:
+            PrettyOutput.print("没有活动的会话可供保存", OutputType.WARNING)
+            return False
+
+        state = {
+            "chat_id": self.chat_id,
+            "model_name": self.model_name,
+            "system_message": self.system_message,
+            "first_chat": self.first_chat,
+            "uploaded_files": self.uploaded_files,
+        }
+
+        try:
+            with open(file_path, "w", encoding="utf-8") as f:
+                json.dump(state, f, ensure_ascii=False, indent=4)
+            self._saved = True
+            PrettyOutput.print(f"会话已成功保存到 {file_path}", OutputType.SUCCESS)
+            return True
+        except Exception as e:
+            PrettyOutput.print(f"保存会话失败: {str(e)}", OutputType.ERROR)
+            return False
+
+    def restore(self, file_path: str) -> bool:
+        """Restore chat session from a file."""
+        try:
+            with open(file_path, "r", encoding="utf-8") as f:
+                state = json.load(f)
+
+            self.chat_id = state.get("chat_id", "")
+            self.model_name = state.get("model_name", "kimi")
+            self.system_message = state.get("system_message", "")
+            self.first_chat = state.get("first_chat", True)
+            self.uploaded_files = state.get("uploaded_files", [])
+            self._saved = True
+
+            PrettyOutput.print(f"从 {file_path} 成功恢复会话", OutputType.SUCCESS)
+            return True
+        except FileNotFoundError:
+            PrettyOutput.print(f"会话文件未找到: {file_path}", OutputType.ERROR)
+            return False
+        except Exception as e:
+            PrettyOutput.print(f"恢复会话失败: {str(e)}", OutputType.ERROR)
+            return False
+
     def name(self) -> str:
         """Model name"""
         return self.model_name
 
+    @classmethod
+    def platform_name(cls) -> str:
+        """Platform name"""
+        return "kimi"
+
     def support_web(self) -> bool:
         """Kimi平台支持web功能"""
         return True
