@@ -7,13 +7,10 @@ import time
 import urllib.parse
 from typing import Dict, Generator, List, Tuple
 
-import requests
-from PIL import Image
-from yaspin import yaspin
-from yaspin.api import Yaspin
-from yaspin.spinners import Spinners
+from PIL import Image  # type: ignore
 
 from jarvis.jarvis_platform.base import BasePlatform
+from jarvis.jarvis_utils import http
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 from jarvis.jarvis_utils.utils import while_success
 
@@ -21,8 +18,6 @@ from jarvis.jarvis_utils.utils import while_success
 class YuanbaoPlatform(BasePlatform):
     """Hunyuan模型实现"""
 
-    platform_name = "yuanbao"
-
     def get_model_list(self) -> List[Tuple[str, str]]:
         """获取支持的模型列表"""
         return [
@@ -40,10 +35,12 @@ class YuanbaoPlatform(BasePlatform):
         self.conversation_id = ""  # 会话ID，用于标识当前对话
         # 从环境变量中获取必要参数
         self.cookies = os.getenv("YUANBAO_COOKIES")  # 认证cookies
-        self.agent_id = os.getenv("YUANBAO_AGENT_ID")  # 代理ID
+        self.agent_id = "naQivTmsDa"
 
         if not self.cookies:
-            PrettyOutput.print("YUANBAO_COOKIES 未设置", OutputType.WARNING)
+            raise ValueError(
+                "YUANBAO_COOKIES environment variable not set. Please provide your cookies to use the Yuanbao platform."
+            )
 
         self.system_message = ""  # 系统消息，用于初始化对话
         self.first_chat = True  # 标识是否为第一次对话
@@ -98,7 +95,8 @@ class YuanbaoPlatform(BasePlatform):
 
         try:
             response = while_success(
-                lambda: requests.post(url, headers=headers, data=payload, timeout=600), sleep_time=5
+                lambda: http.post(url, headers=headers, data=payload),
+                sleep_time=5,
             )
             response_json = response.json()
 
@@ -135,115 +133,106 @@ class YuanbaoPlatform(BasePlatform):
 
         for file_path in file_list:
             file_name = os.path.basename(file_path)
-            with yaspin(Spinners.dots, text=f"上传文件 {file_name}") as spinner:
-                try:
+            print(f"🔍 上传文件 {file_name}")
+            try:
+                # 1. Prepare the file information
+                print(f"🔍 准备文件信息: {file_name}")
+                file_size = os.path.getsize(file_path)
+                file_extension = os.path.splitext(file_path)[1].lower().lstrip(".")
 
-                    # 1. Prepare the file information
-                    spinner.text = f"准备文件信息: {file_name}"
-                    file_size = os.path.getsize(file_path)
-                    file_extension = os.path.splitext(file_path)[1].lower().lstrip(".")
+                # Determine file_type using file extension
+                file_type = "txt"  # Default type
 
-                    # Determine file_type using file extension
-                    file_type = "txt"  # Default type
+                # Image types
+                if file_extension in ["jpg", "jpeg", "png", "webp", "bmp", "gif"]:
+                    file_type = "image"
+                # PDF type
+                elif file_extension == "pdf":
+                    file_type = "pdf"
+                # Spreadsheet types
+                elif file_extension in ["xls", "xlsx"]:
+                    file_type = "excel"
+                # Presentation types
+                elif file_extension in ["ppt", "pptx"]:
+                    file_type = "ppt"
+                # Document types
+                elif file_extension in ["doc", "docx"]:
+                    file_type = "doc"
+                # Code file types
+                elif file_extension in [
+                    "bat",
+                    "c",
+                    "cpp",
+                    "cs",
+                    "css",
+                    "go",
+                    "h",
+                    "hpp",
+                    "ini",
+                    "java",
+                    "js",
+                    "json",
+                    "log",
+                    "lua",
+                    "php",
+                    "pl",
+                    "py",
+                    "rb",
+                    "sh",
+                    "sql",
+                    "swift",
+                    "tex",
+                    "toml",
+                    "vue",
+                    "yaml",
+                    "yml",
+                    "rs",
+                ]:
+                    file_type = "code"
 
-                    # Image types
-                    if file_extension in ["jpg", "jpeg", "png", "webp", "bmp", "gif"]:
-                        file_type = "image"
-                    # PDF type
-                    elif file_extension == "pdf":
-                        file_type = "pdf"
-                    # Spreadsheet types
-                    elif file_extension in ["xls", "xlsx"]:
-                        file_type = "excel"
-                    # Presentation types
-                    elif file_extension in ["ppt", "pptx"]:
-                        file_type = "ppt"
-                    # Document types
-                    elif file_extension in ["doc", "docx"]:
-                        file_type = "doc"
-                    # Code file types
-                    elif file_extension in [
-                        "bat",
-                        "c",
-                        "cpp",
-                        "cs",
-                        "css",
-                        "go",
-                        "h",
-                        "hpp",
-                        "ini",
-                        "java",
-                        "js",
-                        "json",
-                        "log",
-                        "lua",
-                        "php",
-                        "pl",
-                        "py",
-                        "rb",
-                        "sh",
-                        "sql",
-                        "swift",
-                        "tex",
-                        "toml",
-                        "vue",
-                        "yaml",
-                        "yml",
-                        "rs",
-                    ]:
-                        file_type = "code"
-
-                    # 2. Generate upload information
-                    spinner.text = f"获取上传信息: {file_name}"
-                    upload_info = self._generate_upload_info(file_name)
-                    if not upload_info:
-                        spinner.text = f"无法获取文件 {file_name} 的上传信息"
-                        spinner.fail("❌")
-                        return False
-
-                    # 3. Upload the file to COS
-                    spinner.text = f"上传文件到云存储: {file_name}"
-                    upload_success = self._upload_file_to_cos(
-                        file_path, upload_info, spinner
-                    )
-                    if not upload_success:
-                        spinner.text = f"上传文件 {file_name} 失败"
-                        spinner.fail("❌")
-                        return False
-
-                    # 4. Create file metadata for chat
-                    spinner.text = f"生成文件元数据: {file_name}"
-                    file_metadata = {
-                        "type": file_type,
-                        "docType": file_extension if file_extension else file_type,
-                        "url": upload_info.get("resourceUrl", ""),
-                        "fileName": file_name,
-                        "size": file_size,
-                        "width": 0,
-                        "height": 0,
-                    }
-
-                    # Get image dimensions if it's an image file
-                    if file_type == "image":
-                        try:
-                            with Image.open(file_path) as img:
-                                file_metadata["width"] = img.width
-                                file_metadata["height"] = img.height
-                        except Exception as e:
-                            spinner.write(
-                                f"⚠️ 无法获取图片 {file_name} 的尺寸: {str(e)}"
-                            )
-
-                    uploaded_files.append(file_metadata)
-                    spinner.text = f"文件 {file_name} 上传成功"
-                    spinner.ok("✅")
-                    time.sleep(3)  # 上传成功后等待3秒
-
-                except Exception as e:
-                    spinner.text = f"上传文件 {file_path} 时出错: {str(e)}"
-                    spinner.fail("❌")
+                # 2. Generate upload information
+                print(f"🔍 获取上传信息: {file_name}")
+                upload_info = self._generate_upload_info(file_name)
+                if not upload_info:
+                    print(f"❌ 无法获取文件 {file_name} 的上传信息")
                     return False
 
+                # 3. Upload the file to COS
+                print(f"🔍 上传文件到云存储: {file_name}")
+                upload_success = self._upload_file_to_cos(file_path, upload_info)
+                if not upload_success:
+                    print(f"❌ 上传文件 {file_name} 失败")
+                    return False
+
+                # 4. Create file metadata for chat
+                print(f"🔍 生成文件元数据: {file_name}")
+                file_metadata = {
+                    "type": file_type,
+                    "docType": file_extension if file_extension else file_type,
+                    "url": upload_info.get("resourceUrl", ""),
+                    "fileName": file_name,
+                    "size": file_size,
+                    "width": 0,
+                    "height": 0,
+                }
+
+                # Get image dimensions if it's an image file
+                if file_type == "image":
+                    try:
+                        with Image.open(file_path) as img:
+                            file_metadata["width"] = img.width
+                            file_metadata["height"] = img.height
+                    except Exception as e:
+                        print(f"⚠️ 无法获取图片 {file_name} 的尺寸: {str(e)}")
+
+                uploaded_files.append(file_metadata)
+                print(f"✅ 文件 {file_name} 上传成功")
+                time.sleep(3)  # 上传成功后等待3秒
+
+            except Exception as e:
+                print(f"❌ 上传文件 {file_path} 时出错: {str(e)}")
+                return False
+
         self.multimedia = uploaded_files
         return True
 
@@ -264,7 +253,8 @@ class YuanbaoPlatform(BasePlatform):
 
         try:
             response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload, timeout=600), sleep_time=5
+                lambda: http.post(url, headers=headers, json=payload),
+                sleep_time=5,
             )
 
             if response.status_code != 200:
@@ -283,9 +273,7 @@ class YuanbaoPlatform(BasePlatform):
             PrettyOutput.print(f"获取上传信息时出错: {str(e)}", OutputType.ERROR)
             return {}
 
-    def _upload_file_to_cos(
-        self, file_path: str, upload_info: Dict, spinner: Yaspin
-    ) -> bool:
+    def _upload_file_to_cos(self, file_path: str, upload_info: Dict) -> bool:
         """使用提供的上传信息将文件上传到腾讯COS
 
         参数:
@@ -313,7 +301,7 @@ class YuanbaoPlatform(BasePlatform):
             with open(file_path, "rb") as file:
                 file_content = file.read()
 
-            spinner.write(f"ℹ️  上传文件大小: {len(file_content)}")
+            print(f"ℹ️  上传文件大小: {len(file_content)}")
 
             # Prepare headers for PUT request
             host = f"{upload_info['bucketName']}.{upload_info.get('accelerateDomain', 'cos.accelerate.myqcloud.com')}"
@@ -342,7 +330,7 @@ class YuanbaoPlatform(BasePlatform):
             )
 
             # Upload the file
-            response = requests.put(url, headers=headers, data=file_content)
+            response = http.put(url, headers=headers, data=file_content)
 
             if response.status_code not in [200, 204]:
                 PrettyOutput.print(
@@ -479,58 +467,66 @@ class YuanbaoPlatform(BasePlatform):
             payload["displayPrompt"] = payload["prompt"]
 
         try:
-            # 发送消息请求，获取流式响应
-            response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload, stream=True, timeout=600),
+            # 使用新的stream_post接口发送消息请求，获取流式响应
+            response_stream = while_success(
+                lambda: http.stream_post(url, headers=headers, json=payload),
                 sleep_time=5,
             )
 
-            # 检查响应状态
-            if response.status_code != 200:
-                error_msg = f"发送消息失败，状态码: {response.status_code}"
-                if hasattr(response, "text"):
-                    error_msg += f", 响应: {response.text}"
-                raise Exception(error_msg)
-
             in_thinking = False
+            response_data = b""
 
-            # 处理SSE流响应
-            for line in response.iter_lines():
-                if not line:
+            # 处理流式响应
+            for chunk in response_stream:
+                response_data += chunk
+
+                # 尝试解析SSE格式的数据
+                try:
+                    # 查找完整的数据行
+                    lines = response_data.decode("utf-8").split("\n")
+                    response_data = b""  # 重置缓冲区
+
+                    for line in lines:
+                        if not line.strip():
+                            continue
+
+                        # SSE格式的行通常以"data: "开头
+                        if line.startswith("data: "):
+                            try:
+                                data_str = line[6:]  # 移除"data: "前缀
+
+                                # 检查结束标志
+                                if data_str == "[DONE]":
+                                    self.first_chat = False
+                                    return None
+
+                                data = json.loads(data_str)
+
+                                # 处理文本类型的消息
+                                if data.get("type") == "text":
+                                    if in_thinking:
+                                        yield "</think>\n"
+                                        in_thinking = False
+                                    msg = data.get("msg", "")
+                                    if msg:
+                                        yield msg
+
+                                # 处理思考中的消息
+                                elif data.get("type") == "think":
+                                    if not in_thinking:
+                                        yield "<think>\n"
+                                        in_thinking = True
+                                    think_content = data.get("content", "")
+                                    if think_content:
+                                        yield think_content
+
+                            except json.JSONDecodeError:
+                                pass
+
+                except UnicodeDecodeError:
+                    # 如果解码失败，继续累积数据
                     continue
 
-                line_str = line.decode("utf-8")
-
-                # SSE格式的行通常以"data: "开头
-                if line_str.startswith("data: "):
-                    try:
-                        data_str = line_str[6:]  # 移除"data: "前缀
-                        data = json.loads(data_str)
-
-                        # 处理文本类型的消息
-                        if data.get("type") == "text":
-                            if in_thinking:
-                                yield "</think>\n"
-                                in_thinking = False
-                            msg = data.get("msg", "")
-                            if msg:
-                                yield msg
-
-                        # 处理思考中的消息
-                        elif data.get("type") == "think":
-                            if not in_thinking:
-                                yield "<think>\n"
-                                in_thinking = True
-                            think_content = data.get("content", "")
-                            if think_content:
-                                yield think_content
-
-                    except json.JSONDecodeError:
-                        pass
-
-                # 检测结束标志
-                elif line_str == "data: [DONE]":
-                    return None
             self.first_chat = False
             return None
 
@@ -556,7 +552,8 @@ class YuanbaoPlatform(BasePlatform):
 
         try:
             response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload, timeout=600), sleep_time=5
+                lambda: http.post(url, headers=headers, json=payload),
+                sleep_time=5,
             )
 
             if response.status_code == 200:
@@ -574,10 +571,61 @@ class YuanbaoPlatform(BasePlatform):
             PrettyOutput.print(f"删除会话时发生错误: {str(e)}", OutputType.ERROR)
             return False
 
+    def save(self, file_path: str) -> bool:
+        """Save chat session to a file."""
+        if not self.conversation_id:
+            PrettyOutput.print("没有活动的会话可供保存", OutputType.WARNING)
+            return False
+
+        state = {
+            "conversation_id": self.conversation_id,
+            "system_message": self.system_message,
+            "first_chat": self.first_chat,
+            "model_name": self.model_name,
+            "multimedia": self.multimedia,
+        }
+
+        try:
+            with open(file_path, "w", encoding="utf-8") as f:
+                json.dump(state, f, ensure_ascii=False, indent=4)
+            self._saved = True
+            PrettyOutput.print(f"会话已成功保存到 {file_path}", OutputType.SUCCESS)
+            return True
+        except Exception as e:
+            PrettyOutput.print(f"保存会话失败: {str(e)}", OutputType.ERROR)
+            return False
+
+    def restore(self, file_path: str) -> bool:
+        """Restore chat session from a file."""
+        try:
+            with open(file_path, "r", encoding="utf-8") as f:
+                state = json.load(f)
+
+            self.conversation_id = state.get("conversation_id", "")
+            self.system_message = state.get("system_message", "")
+            self.first_chat = state.get("first_chat", True)
+            self.model_name = state.get("model_name", "deep_seek_v3")
+            self.multimedia = state.get("multimedia", [])
+            self._saved = True
+
+            PrettyOutput.print(f"从 {file_path} 成功恢复会话", OutputType.SUCCESS)
+            return True
+        except FileNotFoundError:
+            PrettyOutput.print(f"会话文件未找到: {file_path}", OutputType.ERROR)
+            return False
+        except Exception as e:
+            PrettyOutput.print(f"恢复会话失败: {str(e)}", OutputType.ERROR)
+            return False
+
     def name(self) -> str:
         """模型名称"""
         return self.model_name
 
+    @classmethod
+    def platform_name(cls) -> str:
+        """平台名称"""
+        return "yuanbao"
+
     def support_web(self) -> bool:
         """Yuanbao平台支持web功能"""
         return True
