@@ -7,20 +7,15 @@
 2. 支持单个文件的编辑操作，包括创建新文件
 3. 实现原子操作：所有修改要么全部成功，要么全部回滚
 4. 严格匹配控制：每个搜索文本必须且只能匹配一次
-5. 支持两种编辑模式：快速编辑(fast_edit)和AI辅助编辑(slow_edit)
 
 核心特性:
 - 支持不存在的文件和空文件处理
 - 自动创建所需目录结构
 - 完善的错误处理和回滚机制
 - 严格的格式保持要求
-- 支持大文件处理(自动上传到模型平台)
-- 提供3次重试机制确保操作可靠性
 """
 from typing import Any, Dict
 
-from yaspin import yaspin
-
 from jarvis.jarvis_agent.edit_file_handler import EditFileHandler
 
 
@@ -34,8 +29,8 @@ class FileSearchReplaceTool:
 1. 指定需要修改的文件路径（单个或多个）
 2. 提供一组或多组修改，每个修改包含:
    - reason: 修改原因描述
-   - search: 需要查找的原始代码(必须包含足够上下文)
-   - replace: 替换后的新代码
+   - SEARCH: 需要查找的原始代码(必须包含足够上下文)
+   - REPLACE: 替换后的新代码
 3. 工具会自动选择最适合的编辑模式
 
 ## 核心原则
@@ -62,12 +57,18 @@ class FileSearchReplaceTool:
                             "items": {
                                 "type": "object",
                                 "properties": {
-                                    "reason": {"type": "string", "description": "修改的原因"},
-                                    "search": {
+                                    "reason": {
+                                        "type": "string",
+                                        "description": "修改的原因",
+                                    },
+                                    "SEARCH": {
                                         "type": "string",
                                         "description": "需要查找的原始代码",
                                     },
-                                    "replace": {"type": "string", "description": "替换后的新代码"},
+                                    "REPLACE": {
+                                        "type": "string",
+                                        "description": "替换后的新代码",
+                                    },
                                 },
                             },
                         },
@@ -79,7 +80,6 @@ class FileSearchReplaceTool:
         "required": ["files"],
     }
 
-
     def execute(self, args: Dict) -> Dict[str, Any]:
         """执行文件编辑操作，支持快速编辑和AI辅助编辑两种模式。
 
@@ -96,8 +96,8 @@ class FileSearchReplaceTool:
                     - path: 要修改的文件路径
                     - changes: 修改列表，每个修改包含:
                         - reason: 修改原因描述
-                        - search: 需要查找的原始代码(必须包含足够上下文)
-                        - replace: 替换后的新代码
+                        - SEARCH: 需要查找的原始代码(必须包含足够上下文)
+                        - REPLACE: 替换后的新代码
 
         返回:
             Dict[str, Any] 包含:
@@ -131,7 +131,6 @@ class FileSearchReplaceTool:
         for file_info in args["files"]:
             file_path = os.path.abspath(file_info["path"])
             changes = file_info["changes"]
-            agent = args.get("agent", None)
 
             # 创建已处理文件变量，用于失败时回滚
             original_content = None
@@ -149,49 +148,28 @@ class FileSearchReplaceTool:
                             content = f.read()
                             original_content = content
 
-                    if file_exists and agent:
-                        files = agent.get_user_data("files")
-                        if not files or file_path not in files:
-                            file_results.append({
+                    print(f"⚙️ 正在处理文件 {file_path}...")
+                    success, temp_content = EditFileHandler._fast_edit(
+                        file_path, changes
+                    )
+                    if not success:
+                        print(f"❌ 文件 {file_path} 处理失败")
+                        file_results.append(
+                            {
                                 "file": file_path,
                                 "success": False,
                                 "stdout": "",
-                                "stderr": f"请先读取文件 {file_path} 的内容后再编辑"
-                            })
-                            continue
+                                "stderr": temp_content,
+                            }
+                        )
+                        continue
 
-                    with yaspin(
-                        text=f"正在处理文件 {file_path}...", color="cyan"
-                    ) as spinner:
-                        # 首先尝试fast_edit模式
-                        success, temp_content = EditFileHandler._fast_edit(file_path, changes, spinner)
-                        if not success:
-                            # 如果fast_edit失败，尝试slow_edit模式
-                            success, temp_content = EditFileHandler._slow_edit(
-                                file_path,
-                                changes,
-                                spinner,
-                                agent
-                            )
-                            if not success:
-                                spinner.text = f"文件 {file_path} 处理失败"
-                                spinner.fail("❌")
-                                file_results.append({
-                                    "file": file_path,
-                                    "success": False,
-                                    "stdout": "",
-                                    "stderr": temp_content
-                                })
-                                continue
-                            else:
-                                spinner.text = f"文件 {file_path} 内容生成完成"
-                                spinner.ok("✅")
-                        else:
-                            spinner.text = f"文件 {file_path} 内容生成完成"
-                            spinner.ok("✅")
+                    print(f"✅ 文件 {file_path} 内容生成完成")
 
                     # 只有当所有替换操作都成功时，才写回文件
-                    if success and (temp_content != original_content or not file_exists):
+                    if success and (
+                        temp_content != original_content or not file_exists
+                    ):
                         # 确保目录存在
                         os.makedirs(
                             os.path.dirname(os.path.abspath(file_path)), exist_ok=True
@@ -208,24 +186,28 @@ class FileSearchReplaceTool:
                         PrettyOutput.print(stdout_message, OutputType.SUCCESS)
                         overall_success = True
 
-                        file_results.append({
-                            "file": file_path,
-                            "success": True,
-                            "stdout": stdout_message,
-                            "stderr": ""
-                        })
+                        file_results.append(
+                            {
+                                "file": file_path,
+                                "success": True,
+                                "stdout": stdout_message,
+                                "stderr": "",
+                            }
+                        )
 
                 except Exception as e:
                     stderr_message = f"处理文件 {file_path} 时出错: {str(e)}"
                     stderr_messages.append(stderr_message)
                     PrettyOutput.print(stderr_message, OutputType.WARNING)
                     file_success = False
-                    file_results.append({
-                        "file": file_path,
-                        "success": False,
-                        "stdout": "",
-                        "stderr": stderr_message
-                    })
+                    file_results.append(
+                        {
+                            "file": file_path,
+                            "success": False,
+                            "stdout": "",
+                            "stderr": stderr_message,
+                        }
+                    )
 
             except Exception as e:
                 error_msg = f"文件搜索替换操作失败: {str(e)}"
@@ -251,12 +233,14 @@ class FileSearchReplaceTool:
                     except:
                         stderr_messages.append(f"回滚文件失败: {file_path}")
 
-                file_results.append({
-                    "file": file_path,
-                    "success": False,
-                    "stdout": "",
-                    "stderr": error_msg
-                })
+                file_results.append(
+                    {
+                        "file": file_path,
+                        "success": False,
+                        "stdout": "",
+                        "stderr": error_msg,
+                    }
+                )
 
         # 整合所有错误信息到stderr
         all_stderr = []
@@ -267,5 +251,5 @@ class FileSearchReplaceTool:
         return {
             "success": overall_success,
             "stdout": "\n".join(stdout_messages) if overall_success else "",
-            "stderr": "\n".join(all_stderr) if not overall_success else ""
+            "stderr": "\n".join(all_stderr) if not overall_success else "",
         }
