@@ -3,7 +3,8 @@ import os
 from functools import lru_cache
 from typing import Any, Dict, List
 
-import yaml
+import torch
+import yaml  # type: ignore
 
 from jarvis.jarvis_utils.builtin_replace_map import BUILTIN_REPLACE_MAP
 
@@ -96,25 +97,21 @@ def get_max_input_token_count() -> int:
     return int(GLOBAL_CONFIG_DATA.get("JARVIS_MAX_INPUT_TOKEN_COUNT", "32000"))
 
 
-def is_auto_complete() -> bool:
-    """
-    检查是否启用了自动补全功能。
-
-    返回：
-        bool: 如果启用了自动补全则返回True，默认为False
-    """
-    return GLOBAL_CONFIG_DATA.get("JARVIS_AUTO_COMPLETE", False) == True
-
-
 def get_shell_name() -> str:
     """
     获取系统shell名称。
 
     返回：
-        str: Shell名称（例如bash, zsh），默认为bash
+        str: Shell名称（例如bash, zsh, fish），默认为bash
+
+    获取顺序：
+    1. 先从GLOBAL_CONFIG_DATA中获取JARVIS_SHELL配置
+    2. 再从GLOBAL_CONFIG_DATA中获取SHELL配置
+    3. 最后从环境变量SHELL获取
+    4. 如果都未配置，则默认返回bash
     """
-    shell_path = GLOBAL_CONFIG_DATA.get("SHELL", "/bin/bash")
-    return os.path.basename(shell_path)
+    shell_path = GLOBAL_CONFIG_DATA.get("SHELL", os.getenv("SHELL", "/bin/bash"))
+    return os.path.basename(shell_path).lower()
 
 
 def get_normal_platform_name() -> str:
@@ -178,17 +175,7 @@ def is_confirm_before_apply_patch() -> bool:
     返回：
         bool: 如果需要确认则返回True，默认为False
     """
-    return GLOBAL_CONFIG_DATA.get("JARVIS_CONFIRM_BEFORE_APPLY_PATCH", True) == True
-
-
-def get_max_tool_call_count() -> int:
-    """
-    获取最大工具调用次数。
-
-    返回：
-        int: 最大连续工具调用次数，默认为20
-    """
-    return int(GLOBAL_CONFIG_DATA.get("JARVIS_MAX_TOOL_CALL_COUNT", "20"))
+    return GLOBAL_CONFIG_DATA.get("JARVIS_CONFIRM_BEFORE_APPLY_PATCH", False) == True
 
 
 def get_data_dir() -> str:
@@ -199,20 +186,9 @@ def get_data_dir() -> str:
         str: 数据目录路径，优先从JARVIS_DATA_PATH环境变量获取，
              如果未设置或为空，则使用~/.jarvis作为默认值
     """
-    data_path = GLOBAL_CONFIG_DATA.get("JARVIS_DATA_PATH", "").strip()
-    if not data_path:
-        return os.path.expanduser("~/.jarvis")
-    return data_path
-
-
-def get_auto_update() -> bool:
-    """
-    获取是否自动更新git仓库。
-
-    返回：
-        bool: 如果需要自动更新则返回True，默认为True
-    """
-    return GLOBAL_CONFIG_DATA.get("JARVIS_AUTO_UPDATE", True) == True
+    return os.path.expanduser(
+        GLOBAL_CONFIG_DATA.get("JARVIS_DATA_PATH", "~/.jarvis").strip()
+    )
 
 
 def get_max_big_content_size() -> int:
@@ -265,14 +241,14 @@ def is_print_prompt() -> bool:
     return GLOBAL_CONFIG_DATA.get("JARVIS_PRINT_PROMPT", False) == True
 
 
-def get_history_count() -> int:
+def is_enable_static_analysis() -> bool:
     """
-    获取是否启用历史记录功能。
+    获取是否启用静态代码分析。
 
     返回：
-        bool: 如果启用历史记录则返回True，默认为False
+        bool: 如果启用静态代码分析则返回True，默认为True
     """
-    return GLOBAL_CONFIG_DATA.get("JARVIS_USE_HISTORY_COUNT", 0)
+    return GLOBAL_CONFIG_DATA.get("JARVIS_ENABLE_STATIC_ANALYSIS", True) is True
 
 
 def get_mcp_config() -> List[Dict[str, Any]]:
@@ -283,3 +259,58 @@ def get_mcp_config() -> List[Dict[str, Any]]:
         List[Dict[str, Any]]: MCP配置项列表，如果未配置则返回空列表
     """
     return GLOBAL_CONFIG_DATA.get("JARVIS_MCP", [])
+
+
+# ==============================================================================
+# RAG Framework Configuration
+# ==============================================================================
+
+
+def get_rag_config() -> Dict[str, Any]:
+    """
+    获取RAG框架的配置。
+
+    返回:
+        Dict[str, Any]: RAG配置字典
+    """
+    return GLOBAL_CONFIG_DATA.get("JARVIS_RAG", {})
+
+
+def get_rag_embedding_model() -> str:
+    """
+    获取RAG嵌入模型的名称。
+
+    返回:
+        str: 嵌入模型的名称
+    """
+    return get_rag_config().get("embedding_model", "BAAI/bge-base-zh-v1.5")
+
+
+def get_rag_rerank_model() -> str:
+    """
+    获取RAG rerank模型的名称。
+
+    返回:
+        str: rerank模型的名称
+    """
+    return get_rag_config().get("rerank_model", "BAAI/bge-reranker-base")
+
+
+def get_rag_embedding_cache_path() -> str:
+    """
+    获取RAG嵌入缓存的路径。
+
+    返回:
+        str: 缓存路径
+    """
+    return ".jarvis/rag/embeddings"
+
+
+def get_rag_vector_db_path() -> str:
+    """
+    获取RAG向量数据库的路径。
+
+    返回:
+        str: 数据库路径
+    """
+    return ".jarvis/rag/vectordb"
