@@ -9,17 +9,19 @@ Git工具模块
 - 获取最新提交的哈希值
 - 从Git差异中提取修改的行范围
 """
+import datetime
 import os
 import re
 import subprocess
-from typing import Any, Dict, List, Tuple
+import sys
+from typing import Any, Dict, List, Set, Tuple
 
-from jarvis.jarvis_utils.config import get_auto_update, is_confirm_before_apply_patch
+from jarvis.jarvis_utils.config import is_confirm_before_apply_patch
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
-from jarvis.jarvis_utils.utils import user_confirm
+from jarvis.jarvis_utils.input import user_confirm
 
 
-def find_git_root(start_dir: str = ".") -> str:
+def find_git_root_and_cd(start_dir: str = ".") -> str:
     """
     切换到给定路径的Git根目录，如果不是Git仓库则初始化。
 
@@ -212,14 +214,15 @@ def handle_commit_workflow() -> bool:
     Returns:
         bool: 提交是否成功
     """
-    if is_confirm_before_apply_patch() and not user_confirm("是否要提交代码？", default=True):
+    if is_confirm_before_apply_patch() and not user_confirm(
+        "是否要提交代码？", default=True
+    ):
         revert_change()
         return False
 
     import subprocess
 
     try:
-
         confirm_add_new_files()
 
         if not has_uncommitted_changes():
@@ -337,13 +340,24 @@ def check_and_update_git_repo(repo_path: str) -> bool:
         bool: 是否执行了更新
     """
     curr_dir = os.path.abspath(os.getcwd())
-    git_root = find_git_root(repo_path)
+    git_root = find_git_root_and_cd(repo_path)
     if git_root is None:
         return False
 
     try:
-        if not get_auto_update():
-            return False
+        # 检查最新提交时间是否为今天
+        commit_date_result = subprocess.run(
+            ["git", "log", "-1", "--format=%cd", "--date=short"],
+            cwd=git_root,
+            capture_output=True,
+            text=True,
+        )
+        if commit_date_result.returncode == 0:
+            commit_date = commit_date_result.stdout.strip()
+            today = datetime.date.today().strftime("%Y-%m-%d")
+            if commit_date == today:
+                return False
+
         # 检查是否有未提交的修改
         if has_uncommitted_changes():
             return False
@@ -394,7 +408,52 @@ def check_and_update_git_repo(repo_path: str) -> bool:
                 f"Jarvis已更新到tag {remote_tag_result.stdout.strip()}",
                 OutputType.SUCCESS,
             )
-            return True
+
+            # 执行pip安装更新代码
+            try:
+                PrettyOutput.print("正在安装更新后的代码...", OutputType.INFO)
+
+                # 检查是否在虚拟环境中
+                in_venv = hasattr(sys, "real_prefix") or (
+                    hasattr(sys, "base_prefix") and sys.base_prefix != sys.prefix
+                )
+
+                # 尝试普通安装
+                install_cmd = [sys.executable, "-m", "pip", "install", "-e", "."]
+                result = subprocess.run(
+                    install_cmd, cwd=git_root, capture_output=True, text=True
+                )
+
+                if result.returncode == 0:
+                    PrettyOutput.print("代码更新安装成功", OutputType.SUCCESS)
+                    return True
+
+                # 处理权限错误
+                error_msg = result.stderr.strip()
+                if not in_venv and (
+                    "Permission denied" in error_msg or "not writeable" in error_msg
+                ):
+                    if user_confirm(
+                        "检测到权限问题，是否尝试用户级安装(--user)？", True
+                    ):
+                        user_result = subprocess.run(
+                            install_cmd + ["--user"],
+                            cwd=git_root,
+                            capture_output=True,
+                            text=True,
+                        )
+                        if user_result.returncode == 0:
+                            PrettyOutput.print("用户级代码安装成功", OutputType.SUCCESS)
+                            return True
+                        error_msg = user_result.stderr.strip()
+
+                PrettyOutput.print(f"代码安装失败: {error_msg}", OutputType.ERROR)
+                return False
+            except Exception as e:
+                PrettyOutput.print(
+                    f"安装过程中发生意外错误: {str(e)}", OutputType.ERROR
+                )
+                return False
         return False
     except Exception as e:
         PrettyOutput.print(f"Git仓库更新检查失败: {e}", OutputType.WARNING)
@@ -411,7 +470,7 @@ def get_diff_file_list() -> List[str]:
     """
     try:
         confirm_add_new_files()
-        
+
         # 暂存新增文件
         subprocess.run(["git", "add", "-N", "."], check=True)
 
@@ -424,7 +483,9 @@ def get_diff_file_list() -> List[str]:
         subprocess.run(["git", "reset"], check=True)
 
         if result.returncode != 0:
-            PrettyOutput.print(f"获取差异文件列表失败: {result.stderr}", OutputType.ERROR)
+            PrettyOutput.print(
+                f"获取差异文件列表失败: {result.stderr}", OutputType.ERROR
+            )
             return []
 
         return [f for f in result.stdout.splitlines() if f]
@@ -455,9 +516,22 @@ def get_recent_commits_with_files() -> List[Dict[str, Any]]:
             失败时返回空列表
     """
     try:
-        # 获取最近5次提交的基本信息
+        # 获取当前git用户名
+        current_author = subprocess.run(
+            ["git", "config", "user.name"],
+            capture_output=True,
+            text=True,
+        ).stdout.strip()
+
+        # 获取当前用户最近5次提交的基本信息
         result = subprocess.run(
-            ["git", "log", "-5", "--pretty=format:%H%n%s%n%an%n%ad"],
+            [
+                "git",
+                "log",
+                "-5",
+                "--author=" + current_author,
+                "--pretty=format:%H%n%s%n%an%n%ad",
+            ],
             capture_output=True,
             text=True,
         )
@@ -488,14 +562,15 @@ def get_recent_commits_with_files() -> List[Dict[str, Any]]:
             )
             if files_result.returncode == 0:
                 file_lines = files_result.stdout.splitlines()
-                unique_files = set(filter(None, file_lines))
-                commit["files"] = list(unique_files)[:20]  # 限制最多20个文件
+                unique_files: Set[str] = set(filter(None, file_lines))
+                commit["files"] = list(unique_files)[:20]  # type: ignore[list-item] # 限制最多20个文件
 
         return commits
 
     except subprocess.CalledProcessError:
         return []
 
+
 def _get_new_files() -> List[str]:
     """获取新增文件列表"""
     return subprocess.run(
@@ -505,8 +580,10 @@ def _get_new_files() -> List[str]:
         check=True,
     ).stdout.splitlines()
 
+
 def confirm_add_new_files() -> None:
     """确认新增文件、代码行数和二进制文件"""
+
     def _get_added_lines() -> int:
         """获取新增代码行数"""
         diff_stats = subprocess.run(
@@ -515,7 +592,7 @@ def confirm_add_new_files() -> None:
             text=True,
             check=True,
         ).stdout.splitlines()
-        
+
         added_lines = 0
         for stat in diff_stats:
             parts = stat.split()
@@ -531,55 +608,58 @@ def confirm_add_new_files() -> None:
         binary_files = []
         for file in files:
             try:
-                with open(file, 'rb') as f:
-                    if b'\x00' in f.read(1024):
+                with open(file, "rb") as f:
+                    if b"\x00" in f.read(1024):
                         binary_files.append(file)
             except (IOError, PermissionError):
                 continue
         return binary_files
 
-    def _check_conditions(new_files: List[str], added_lines: int, binary_files: List[str]) -> bool:
+    def _check_conditions(
+        new_files: List[str], added_lines: int, binary_files: List[str]
+    ) -> bool:
         """检查各种条件并打印提示信息"""
         need_confirm = False
-        
+        output_lines = []
+
         if len(new_files) > 20:
-            PrettyOutput.print(
-                f"检测到{len(new_files)}个新增文件(选择N将重新检测)",
-                OutputType.WARNING
-            )
-            PrettyOutput.print("新增文件列表:", OutputType.INFO)
-            for file in new_files:
-                PrettyOutput.print(f"  - {file}", OutputType.INFO)
+            output_lines.append(f"检测到{len(new_files)}个新增文件(选择N将重新检测)")
+            output_lines.append("新增文件列表:")
+            output_lines.extend(f"  - {file}" for file in new_files)
             need_confirm = True
-        
+
         if added_lines > 500:
-            PrettyOutput.print(
-                f"检测到{added_lines}行新增代码(选择N将重新检测)",
-                OutputType.WARNING
-            )
+            output_lines.append(f"检测到{added_lines}行新增代码(选择N将重新检测)")
             need_confirm = True
-        
+
         if binary_files:
-            PrettyOutput.print(
-                f"检测到{len(binary_files)}个二进制文件(选择N将重新检测)",
-                OutputType.WARNING
+            output_lines.append(
+                f"检测到{len(binary_files)}个二进制文件(选择N将重新检测)"
             )
-            PrettyOutput.print("二进制文件列表:", OutputType.INFO)
-            for file in binary_files:
-                PrettyOutput.print(f"  - {file}", OutputType.INFO)
+            output_lines.append("二进制文件列表:")
+            output_lines.extend(f"  - {file}" for file in binary_files)
             need_confirm = True
-        
+
+        if output_lines:
+            PrettyOutput.print(
+                "\n".join(output_lines),
+                OutputType.WARNING if need_confirm else OutputType.INFO,
+            )
+
         return need_confirm
 
     while True:
         new_files = _get_new_files()
         added_lines = _get_added_lines()
         binary_files = _get_binary_files(new_files)
-        
+
         if not _check_conditions(new_files, added_lines, binary_files):
             break
-            
-        if not user_confirm("是否要添加这些变更（如果不需要请修改.gitignore文件以忽略不需要的文件）？", False):
+
+        if not user_confirm(
+            "是否要添加这些变更（如果不需要请修改.gitignore文件以忽略不需要的文件）？",
+            False,
+        ):
             continue
-            
-        break
\ No newline at end of file
+
+        break
